#!/usr/bin/env python
# -*- coding: utf-8 -*-

# author: Pocholo
# date: 9/27/21

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugins folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY# without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>. 


from gimpfu import *
import gettext
import os, sys,time 

gettext.install("gimp20", gimp.locale_directory, unicode=True)

def pm_white_christmas_card_v2(pattern, crownGrad):
           
    #Initiates the temporary state
    pdb.gimp_context_set_defaults()
	
    #Create new canvas to work on
    width = 1600
    height = 1200
    img = pdb.gimp_image_new(width, height, RGB)
    backLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Wooden Background", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, backLayer, 0)
    pdb.gimp_drawable_fill(backLayer, FILL_TRANSPARENT)
    
    #Create a smaller layer for the wood background (later on would be rescale to image size)
    swidth = 500
    sheight = 375
    centerX = 550 
    centerY = 413
    woodLayer = pdb.gimp_layer_new(img, swidth, sheight, RGBA_IMAGE, "Wood texture", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, woodLayer, 0)
    pdb.gimp_layer_set_offsets(woodLayer, centerX, centerY)     #Center the image to the background
    pdb.gimp_context_set_foreground((150, 150, 150))
    pdb.gimp_drawable_fill(woodLayer, FILL_FOREGROUND)
       
    #Image process
    pdb.gimp_display_new(img)
    
    #Wood texture
    #Solid noise
    cloudLayer = pdb.gimp_layer_new(img, swidth, sheight, RGBA_IMAGE, "Noise cloud", 100, LAYER_MODE_SOFTLIGHT)
    pdb.gimp_image_add_layer(img, cloudLayer, 0)
    pdb.gimp_drawable_fill(cloudLayer, FILL_TRANSPARENT)
    pdb.gimp_layer_set_offsets(cloudLayer, centerX, centerY)     #Center the image to the background
    pdb.plug_in_solid_noise(img, woodLayer, FALSE, FALSE, 0, 15, 10, 10)
    
    #Create wood grain
    woodLayer = pdb.gimp_image_merge_down(img, cloudLayer, CLIP_TO_IMAGE)
    pdb.plug_in_ripple(img, woodLayer, 180, 800, 0, 1, 1, TRUE, TRUE)
    item = pdb.gimp_item_transform_rotate_simple(woodLayer, 
                                                         0,    #rotate_type, 
                                                      TRUE,    #auto_center, 
                                                       800,    #center_x, 
                                                       600)    #center_y
    pdb.gimp_layer_scale(woodLayer, swidth, sheight, TRUE)
    non_empty = pdb.gimp_edit_copy(woodLayer)
    woodCopy = pdb.gimp_layer_new(img, swidth, sheight, RGBA_IMAGE, "Wood copy", 100, LAYER_MODE_SCREEN)
    pdb.gimp_image_add_layer(img, woodCopy, 0)
    pdb.gimp_drawable_fill(woodCopy, FILL_TRANSPARENT)
    pdb.gimp_layer_set_offsets(woodCopy, centerX, centerY)     #Center the image to the background
    woodCopy = pdb.gimp_edit_paste(woodCopy, FALSE)
    pdb.gimp_floating_sel_anchor(woodCopy) 
    woodCopy = pdb.gimp_image_get_layer_by_name(img, "Wood copy")
    pdb.plug_in_wind(img, woodCopy, 0, 3, 12, 0, 0)
    pdb.plug_in_emboss(img, woodCopy, 30, 45, 4, FALSE)
    woodLayer = pdb.gimp_image_merge_down(img, woodCopy, CLIP_TO_IMAGE)
      
    #Wood slat gap
    splitLayer = pdb.gimp_layer_new(img, swidth, sheight, RGBA_IMAGE, "Wood gaps", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, splitLayer, 0)
    pdb.gimp_drawable_fill(splitLayer, FILL_TRANSPARENT)
    pdb.gimp_layer_set_offsets(splitLayer, centerX, centerY)     #Center the image to the background
    pdb.gimp_context_set_background((49, 34, 22))
    pdb.plug_in_blinds(img, splitLayer, 17, 10, 1, FALSE)
    pdb.script_fu_drop_shadow(img, splitLayer, 5, 0, 7, ("White"), 100, FALSE)
    gapshadowLayer = pdb.gimp_image_get_layer_by_name(img, "Drop Shadow")
    pdb.gimp_layer_set_mode(gapshadowLayer, LAYER_MODE_NORMAL)
    pdb.gimp_image_select_item(img, 2, woodLayer)
    pdb.gimp_layer_resize(gapshadowLayer, swidth, sheight, centerX, centerY)
    pdb.gimp_selection_none(img)
    
    #Create a copy
    non_empty = pdb.gimp_edit_copy(woodLayer)
    woodCopy2 = pdb.gimp_layer_new(img, swidth, sheight, RGBA_IMAGE, "Wood copy2", 100, LAYER_MODE_SCREEN)
    pdb.gimp_image_add_layer(img, woodCopy2, 0)
    pdb.gimp_drawable_fill(woodCopy2, FILL_TRANSPARENT)
    pdb.gimp_layer_set_offsets(woodCopy2, centerX, centerY)     #Center the image to the background
    woodCopy2 = pdb.gimp_edit_paste(woodCopy2, FALSE)
    pdb.gimp_floating_sel_anchor(woodCopy2) 
    woodCopy2 = pdb.gimp_image_get_layer_by_name(img, "Wood copy2")
    woodLayer = pdb.gimp_image_merge_down(img, woodCopy2, CLIP_TO_IMAGE)
    
    #Make the wood color 
    non_empty = pdb.gimp_edit_copy(woodLayer)
    woodCopy3 = pdb.gimp_layer_new(img, swidth, sheight, RGBA_IMAGE, "Wood copy3", 100, LAYER_MODE_DIFFERENCE)
    pdb.gimp_image_add_layer(img, woodCopy3, 0)
    pdb.gimp_drawable_fill(woodCopy3, FILL_TRANSPARENT)
    pdb.gimp_layer_set_offsets(woodCopy3, centerX, centerY)     #Center the image to the background
    woodCopy3 = pdb.gimp_edit_paste(woodCopy3, FALSE)
    pdb.gimp_floating_sel_anchor(woodCopy3)
    woodCopy3 = pdb.gimp_image_get_layer_by_name(img, "Wood copy3")
    pdb.plug_in_gauss(img, woodCopy3, 15, 15, 1)   #method=1
    woodLayer = pdb.gimp_image_merge_down(img, woodCopy3, CLIP_TO_IMAGE)
    pdb.gimp_drawable_invert(woodLayer, FALSE)
    pdb.plug_in_normalize(img, woodLayer)
    pdb.gimp_item_set_visible(backLayer, FALSE)
    woodLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_IMAGE)
    pdb.gimp_item_set_visible(backLayer, TRUE)
    pdb.gimp_layer_resize_to_image_size(woodLayer)
    pdb.plug_in_neon(img, woodLayer, 1, 0.25)
    
    #Scale the wood texture to the canvas size 1600 x 1200
    scalex = 1600
    scaley = 1200
    pdb.plug_in_autocrop_layer(img, woodLayer)
    pdb.gimp_layer_scale(woodLayer, scalex, scaley, TRUE)
    backLayer = pdb.gimp_image_merge_down(img, woodLayer, CLIP_TO_IMAGE)
    pdb.gimp_drawable_invert(backLayer, FALSE)
    
    #Tree twigs #1
    #Path for the twigs
    twigs1Layer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Twigs", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, twigs1Layer, 0)
    pdb.gimp_drawable_fill(twigs1Layer, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(1)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.01)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_brush_force(1)
    pdb.gimp_context_set_paint_method("gimp-paintbrush")
    pdb.gimp_paintbrush_default(twigs1Layer, 4, [-100, 580, 1700, 580])
    pdb.plug_in_gmic_qt(img, twigs1Layer, 1, 0, "-v - -fx_spherize 141,1,0,50,97,-0.1,0,0,0") 
    pdb.gimp_image_select_item(img, 2, twigs1Layer)
    pdb.plug_in_sel2path(img, twigs1Layer) 
    pdb.gimp_selection_none(img)
    pdb.gimp_drawable_edit_clear(twigs1Layer)
    
    #Paint the twigs
    pdb.gimp_brushes_set_brush("White Fir branch")
    pdb.gimp_context_set_brush_size(600)
    pdb.gimp_context_set_brush_angle(180)
    pdb.gimp_context_set_brush_spacing(0.20)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_dynamics("Directional Track")
    pdb.gimp_context_set_stroke_method (STROKE_PAINT_METHOD)
    vectors1 = pdb.gimp_image_get_vectors_by_name(img, _("Selection"))    
    pdb.gimp_drawable_edit_stroke_item(twigs1Layer, vectors1)
    pdb.gimp_context_set_dynamics("Dynamics Off")
    
    #Chrismas berries
    berriesLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Christmas Berries", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, berriesLayer, 0)
    pdb.gimp_drawable_fill(berriesLayer, FILL_TRANSPARENT)
    pdb.gimp_image_select_color(img, CHANNEL_OP_REPLACE, twigs1Layer, (81, 46, 8))
    pdb.gimp_selection_shrink(img, 2)
    pdb.plug_in_sel2path(img, twigs1Layer) 
    pdb.gimp_selection_none(img)
    pdb.gimp_brushes_set_brush("Red berries")
    pdb.gimp_context_set_brush_size(60)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(5)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_dynamics("Directional Track")
    pdb.gimp_context_set_stroke_method (STROKE_PAINT_METHOD)
    vectors2 = pdb.gimp_image_get_vectors_by_name(img, _("Selection #1"))    
    pdb.gimp_drawable_edit_stroke_item(berriesLayer, vectors2)
	
	#Second set of twigs
    twigs1Layer2 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Twigs copy", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, twigs1Layer2, 0)
    pdb.gimp_drawable_fill(twigs1Layer2, FILL_TRANSPARENT)
    pdb.gimp_brushes_set_brush("White Fir branch")
    pdb.gimp_context_set_brush_size(600)
    pdb.gimp_context_set_brush_angle(180)
    pdb.gimp_context_set_brush_spacing(1)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_dynamics("Directional Track")
    pdb.gimp_context_set_stroke_method (STROKE_PAINT_METHOD)
    vectors1 = pdb.gimp_image_get_vectors_by_name(img, _("Selection"))    
    pdb.gimp_drawable_edit_stroke_item(twigs1Layer2, vectors1)
    pdb.gimp_context_set_dynamics("Dynamics Off")
	
	#christmas ball 1
    bsize = 500
    ball_1x = 550
    ball_1y = 350
    ballLayer_1 = pdb.gimp_layer_new(img, bsize, bsize, RGBA_IMAGE, "Christmas ball #1", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, ballLayer_1, 0)
    pdb.gimp_context_set_pattern(pattern)
    pdb.gimp_drawable_fill(ballLayer_1, FILL_PATTERN)
    ballLayer_1 = pdb.gimp_item_transform_translate(ballLayer_1, ball_1x, ball_1y)
	
	#using map to create the sphere shape
    pdb.plug_in_map_object(img, ballLayer_1, 
										1,    # Type of mapping (0=plane,1=sphere,2=box,3=cylinder)
							 0.5, 0.5, 2.0,    # viewpoint
							 0.5, 0.5, 0.0,    # object pos
							 1.0, 0.0, 0.0,    # first axis
							 0.0, 1.0, 0.0,    # 2nd axis
							 0.0, 0.0, 0.0,    # axis rotation
										 1,    # Type of lightsource (0=point,1=directional,2=none)
					       (255, 255, 255),    # Lightsource color (r,g,b)
					       -0.5, -0.5, 2.0,    # light position
						 -0.20, -0.40, 1.0,    # light direction
			  0.55, 1.00, 0.20, 0.15, 50.0,    # material (amb, diff, refl, spec, high)
								      True,    # antialias
									 False,    # tile
									 False,    # new image
								      True,    # transparency
									  0.25,    # Sphere/cylinder radius (only used when maptype=1 or 3)
							 0.5, 0.5, 0.5,    # box size
								      1.00,    # unused parameter Cylinder length
									  None,    # Box front face (set these to -1 if not used)
									  None,    # Box back face
									  None,    # Box top face									
									  None,    # Box bottom face
									  None,    # Box left face
									  None,    # Box right face
									  None,    # Cylinder top face (unused parameter)
									  None)    # Cylinder bottom face (unused parameter)
	
    #crown base
    baseLayer = pdb.gimp_layer_new(img, bsize, bsize, RGBA_IMAGE, "Crown base", 100, LAYER_MODE_NORMAL)
    pdb.gimp_layer_add_alpha(baseLayer)
    pdb.gimp_image_add_layer(img, baseLayer, 0)
    pdb.gimp_drawable_fill(baseLayer, FILL_TRANSPARENT)
    baseLayer = pdb.gimp_item_transform_translate(baseLayer, ball_1x, ball_1y)
    pdb.gimp_image_select_round_rectangle(img, 2, 775, 454, 52, 27, 6, 6)
    pdb.gimp_context_set_antialias(TRUE)
    pdb.gimp_context_set_foreground((206, 206, 206))
    pdb.gimp_edit_bucket_fill(baseLayer, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
    pdb.gimp_selection_none(img)
        
    #Create the crown 
    crownLayer = pdb.gimp_layer_new(img, bsize, bsize, RGBA_IMAGE, "Crown", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, crownLayer, 0)
    pdb.gimp_drawable_fill(crownLayer, FILL_TRANSPARENT)
    crownLayer = pdb.gimp_item_transform_translate(crownLayer, ball_1x, ball_1y)
    pdb.gimp_layer_resize_to_image_size(crownLayer)
    pdb.gimp_image_select_round_rectangle(img, 2, 769, 452, 62, 31, 6, 6)
    pdb.gimp_context_set_foreground("White")
    pdb.gimp_edit_bucket_fill(crownLayer, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
    pdb.gimp_context_set_gradient(crownGrad)
    pdb.gimp_context_set_gradient_reverse(TRUE)
    pdb.gimp_drawable_edit_gradient_fill(crownLayer, 0, 0, TRUE, 3, 0.20, TRUE, 770, 470, 830, 464)
    pdb.gimp_selection_none(img)
    
    #Create arches on the crown
    pdb.gimp_context_set_brush("2. Hardness 100")
    pdb.gimp_context_set_brush_size(16)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_hardness(1)
    pdb.gimp_context_set_brush_default_spacing()
    pdb.gimp_eraser_default(crownLayer, 2, [776, 486])
    pdb.gimp_eraser_default(crownLayer, 2, [792, 486])
    pdb.gimp_eraser_default(crownLayer, 2, [808, 486])
    pdb.gimp_eraser_default(crownLayer, 2, [824, 486])
    
    #Create the crown metal ring 
    ringLayer = pdb.gimp_layer_new(img, bsize, bsize, RGBA_IMAGE, "Ring", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, ringLayer, 2)
    pdb.gimp_layer_add_alpha(ringLayer)
    pdb.gimp_drawable_fill(ringLayer, FILL_TRANSPARENT)
    ringLayer = pdb.gimp_item_transform_translate(ringLayer, ball_1x, ball_1y)
    pdb.gimp_image_select_ellipse(img, 2, 775, 412, 50, 60)
    pdb.plug_in_sel2path(img, ringLayer)
    pdb.gimp_selection_none(img)
    pdb.gimp_context_set_foreground("Black")
    pdb.gimp_context_set_line_width(3)
    pdb.gimp_context_set_line_width_unit(PIXELS)
    pdb.gimp_context_set_stroke_method (STROKE_LINE)
    vectors3 = pdb.gimp_image_get_vectors_by_name(img, (_("Selection")+' #2'))
    pdb.gimp_drawable_edit_stroke_item(ringLayer, vectors3)
    ballLayer_1 = pdb.gimp_image_merge_down(img, ringLayer, CLIP_TO_IMAGE)
    ballLayer_1 = pdb.gimp_image_merge_down(img, baseLayer, CLIP_TO_IMAGE)
    ballLayer_1 = pdb.gimp_image_merge_down(img, crownLayer, CLIP_TO_IMAGE)
       
    #Christmas ball 2 
    ball_2x = -60
    ball_2y = 490
    non_empty = pdb.gimp_edit_copy(ballLayer_1)
    ballLayer_2 = pdb.gimp_layer_new(img, bsize, bsize, RGBA_IMAGE, "Christmas ball #2", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, ballLayer_2, 0)
    pdb.gimp_drawable_fill(ballLayer_2, FILL_TRANSPARENT)
    pdb.gimp_layer_set_offsets(ballLayer_2, ball_2x, ball_2y)     #Center the image to the background
    ballLayer_2 = pdb.gimp_edit_paste(ballLayer_2, FALSE)
    pdb.gimp_floating_sel_anchor(ballLayer_2)
    ballLayer_2 = pdb.gimp_image_get_layer_by_name(img, "Christmas ball #2")
	#Christmas ball 3 
    ball_3x = 215
    ball_3y = 290
    non_empty = pdb.gimp_edit_copy(ballLayer_1)
    ballLayer_3 = pdb.gimp_layer_new(img, bsize, bsize, RGBA_IMAGE, "Christmas ball #3", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, ballLayer_3, 0)
    pdb.gimp_drawable_fill(ballLayer_3, FILL_TRANSPARENT)
    pdb.gimp_layer_set_offsets(ballLayer_3, ball_3x, ball_3y)     #Center the image to the background
    ballLayer_3 = pdb.gimp_edit_paste(ballLayer_3, FALSE)
    pdb.gimp_floating_sel_anchor(ballLayer_3)
    ballLayer_3 = pdb.gimp_image_get_layer_by_name(img, "Christmas ball #3")
	#Christmas ball 4 
    ball_4x = 880
    ball_4y = 290
    non_empty = pdb.gimp_edit_copy(ballLayer_1)
    ballLayer_4 = pdb.gimp_layer_new(img, bsize, bsize, RGBA_IMAGE, "Christmas ball #4", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, ballLayer_4, 0)
    pdb.gimp_drawable_fill(ballLayer_4, FILL_TRANSPARENT)
    pdb.gimp_layer_set_offsets(ballLayer_4, ball_4x, ball_4y)     #Center the image to the background
    ballLayer_4 = pdb.gimp_edit_paste(ballLayer_4, FALSE)
    pdb.gimp_floating_sel_anchor(ballLayer_4)
    ballLayer_4 = pdb.gimp_image_get_layer_by_name(img, "Christmas ball #4")
    #Christmas ball 5 
    ball_5x = 1150
    ball_5y = 490
    non_empty = pdb.gimp_edit_copy(ballLayer_1)
    ballLayer_5 = pdb.gimp_layer_new(img, bsize, bsize, RGBA_IMAGE, "Christmas ball #5", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, ballLayer_5, 0)
    pdb.gimp_drawable_fill(ballLayer_5, FILL_TRANSPARENT)
    pdb.gimp_layer_set_offsets(ballLayer_5, ball_5x, ball_5y)     #Center the image to the background
    ballLayer_5 = pdb.gimp_edit_paste(ballLayer_5, FALSE)
    pdb.gimp_floating_sel_anchor(ballLayer_5)
    ballLayer_5 = pdb.gimp_image_get_layer_by_name(img, "Christmas ball #5")
    
    #Strings
    stringLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Strings", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, stringLayer, 8)
    pdb.gimp_layer_add_alpha(stringLayer)
    pdb.gimp_drawable_fill(stringLayer, FILL_TRANSPARENT)
    pdb.gimp_image_select_ellipse(img, 2, 170, 0, 40, 555)
    pdb.plug_in_sel2path(img, stringLayer)
    pdb.gimp_image_select_ellipse(img, 2, 446, -200, 40, 555)
    pdb.plug_in_sel2path(img, stringLayer)
    pdb.gimp_image_select_ellipse(img, 2, 781, -139, 40, 555)
    pdb.plug_in_sel2path(img, stringLayer)
    pdb.gimp_image_select_ellipse(img, 2, 1109, -200, 40, 555)
    pdb.plug_in_sel2path(img, stringLayer)
    pdb.gimp_image_select_ellipse(img, 2, 1380, 0, 40, 555)
    pdb.plug_in_sel2path(img, stringLayer)
    pdb.gimp_selection_none(img)
    pdb.gimp_context_set_foreground("Black")
    pdb.gimp_context_set_line_width(5)
    pdb.gimp_context_set_line_width_unit(PIXELS)
    pdb.gimp_context_set_stroke_method (STROKE_LINE)
    vectors4 = pdb.gimp_image_get_vectors_by_name(img, (_("Selection")+' #3'))
    pdb.gimp_drawable_edit_stroke_item(stringLayer, vectors4)
    vectors5 = pdb.gimp_image_get_vectors_by_name(img, (_("Selection")+' #4'))
    pdb.gimp_drawable_edit_stroke_item(stringLayer, vectors5)
    vectors6 = pdb.gimp_image_get_vectors_by_name(img, (_("Selection")+' #5'))
    pdb.gimp_drawable_edit_stroke_item(stringLayer, vectors6)
    vectors7 = pdb.gimp_image_get_vectors_by_name(img, (_("Selection")+' #6'))
    pdb.gimp_drawable_edit_stroke_item(stringLayer, vectors7)
    vectors8 = pdb.gimp_image_get_vectors_by_name(img, (_("Selection")+' #7'))
    pdb.gimp_drawable_edit_stroke_item(stringLayer, vectors8)
    
    pdb.gimp_item_set_visible(backLayer, FALSE)
    ballsLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_IMAGE)
    pdb.gimp_item_set_name(ballsLayer, "Christmas Tree")
    pdb.gimp_item_set_visible(backLayer, TRUE)
    
    #Drop shadow
    pdb.script_fu_drop_shadow(img, ballsLayer, 15, 40, 24, (0, 0, 0), 85, FALSE)
    pdb.gimp_image_select_item(img, 2, backLayer)
    pdb.plug_in_autocrop(img, backLayer)
    
    #Make active the bottom layer and done
    pdb.gimp_image_set_active_layer(img, backLayer)
    #Set the defaults
    pdb.gimp_context_set_defaults()
     
register(
    "pm_white_christmas_card_v2",
    "Creates a Christmas card",
    "Creates a White Christmas card",
    "Pocholo",
    "Pocholo",
    "2021",
    "Card White Christmas ver2",
    "",
    [
    (PF_PATTERN, "pattern", "Ball Pattern", "Gold and silver Stars.jpg"),
    (PF_GRADIENT, "crownGrad", "Crown metal gradient", "Golden"),
    ],
    [],
    pm_white_christmas_card_v2, menu="<Image>/Pocholo-scripts/Card White Christmas ver2",
    domain=("gimp20", gimp.locale_directory))
main()			